Package: exactRankTests
Title: Exact Distributions for Rank and Permutation Tests
Date: 2026-03-09
Version: 0.8-36
Authors@R: c(person("Torsten", "Hothorn", role = c("aut", "cre"),
                    email = "Torsten.Hothorn@R-project.org"),
             person("Kurt", "Hornik", role = "aut"))
Description: Computes exact conditional p-values and quantiles using an
 implementation of the Shift-Algorithm by Streitberg & Roehmel.
Depends: R (>= 2.4.0), stats, utils
Suggests: survival
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2026-03-09 11:45:39 UTC; hothorn
Author: Torsten Hothorn [aut, cre],
  Kurt Hornik [aut]
Maintainer: Torsten Hothorn <Torsten.Hothorn@R-project.org>
Repository: CRAN
Date/Publication: 2026-03-09 14:10:09 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 16:08:13 UTC; unix
Archs: exactRankTests.so.dSYM
